@@ -20,7 +20,8 @@
 #define COMIC_DATAENGINE_H
 
 #include <Plasma/DataEngine>
-#include <Solid/Networking>
+// Qt
+#include <QNetworkConfigurationManager>
 
 class ComicProvider;
 
@@ -43,22 +44,22 @@ class ComicEngine : public Plasma::DataEngine
 
     public:
         ComicEngine(QObject* parent, const QVariantList& args);
-        ~ComicEngine();
+        ~ComicEngine() override;
 
     public Q_SLOTS:
         void loadProviders();
 
     protected:
         void init();
-        bool sourceRequestEvent(const QString &identifier) Q_DECL_OVERRIDE;
+        bool sourceRequestEvent(const QString &identifier) override;
 
     protected Q_SLOTS:
-        bool updateSourceEvent(const QString &identifier) Q_DECL_OVERRIDE;
+        bool updateSourceEvent(const QString &identifier) override;
 
     private Q_SLOTS:
         void finished(ComicProvider*);
         void error(ComicProvider*);
-        void networkStatusChanged(Solid::Networking::Status);
+        void onOnlineStateChanged(bool);
 
     private:
         bool mEmptySuffix;
@@ -67,6 +68,7 @@ class ComicEngine : public Plasma::DataEngine
         QString mIdentifierError;
         QStringList mProviders;
         QHash<QString, ComicProvider*> m_jobs;
+        QNetworkConfigurationManager m_networkConfigurationManager;
 };
 
 #endif
