@@ -21,7 +21,7 @@ class DictionaryMatchEngine : public QObject
     Q_OBJECT
 
 public:
-    DictionaryMatchEngine(Plasma::DataEngine *dictionaryEngine, QObject *parent = 0);
+    explicit DictionaryMatchEngine(Plasma::DataEngine *dictionaryEngine, QObject *parent = nullptr);
     QString lookupWord(const QString &word);
 
 private:
@@ -34,7 +34,7 @@ private:
     QReadWriteLock m_wordLock;
     Plasma::DataEngine *m_dictionaryEngine;
 
-private slots:
+private Q_SLOTS:
     void dataUpdated(const QString &name, const Plasma::DataEngine::Data &data);
     void sourceAdded(const QString &source);
 
